CpuBackendKind

Enum CpuBackendKind 

pub enum CpuBackendKind {
    Faer,
    Blas,
}
CPU provider selected by a CpuBackend instance.

CPU provider features are additive at compile time; this runtime selector chooses which compiled provider an individual backend uses for provider-owned kernels such as GEMM.

Examples

use tenferro_cpu::CpuBackendKind;

let kind = CpuBackendKind::default_compiled();
assert!(matches!(kind, CpuBackendKind::Faer | CpuBackendKind::Blas));

Variants



Faer

faer-backed CPU kernels.



Blas

BLAS/LAPACK-backed CPU kernels.

Implementations

Source

impl CpuBackendKind

pub fn default_compiled() -> Self

Return the default compiled CPU provider.

BLAS is preferred when both BLAS and faer are compiled in because an application that links a BLAS/LAPACK provider normally expects provider-backed kernels to use it by default.

Examples
use tenferro_cpu::CpuBackendKind;

let _kind = CpuBackendKind::default_compiled();