CpuAffinityPolicy

Enum CpuAffinityPolicy 

pub enum CpuAffinityPolicy {
    DominantInputBytes,
    RequireSingleDomain,
}
Policy used to select a CPU execution domain from input affinity metadata.

Examples

use tenferro_cpu::CpuAffinityPolicy;

let policy = CpuAffinityPolicy::DominantInputBytes;
assert_ne!(policy, CpuAffinityPolicy::RequireSingleDomain);

Variants



DominantInputBytes

Select the domain with the largest total of positive logical input bytes.



RequireSingleDomain

Accept zero or one known input domain and reject mixed known domains.