CpuAffinityResolutionError

Enum CpuAffinityResolutionError 

pub enum CpuAffinityResolutionError {
    LogicalByteCountOverflow {
        domain: CpuDomainId,
    },
    MultipleKnownDomains {
        first: CpuDomainId,
        second: CpuDomainId,
    },
}
Failure to resolve CPU affinity from input metadata.

Examples

use tenferro_cpu::CpuAffinityResolutionError;
use tenferro_tensor::CpuDomainId;

let error = CpuAffinityResolutionError::LogicalByteCountOverflow {
    domain: CpuDomainId::new(4),
};
assert!(error.to_string().contains("4"));

Variants



LogicalByteCountOverflow

Adding logical byte counts overflowed usize for one domain.

Fields

domain: CpuDomainId

Smallest CPU domain whose logical byte total overflowed.



MultipleKnownDomains

Strict policy observed at least two different known domains.

Fields

first: CpuDomainId

Smallest known input domain.

second: CpuDomainId

Second-smallest known input domain.