#[non_exhaustive]pub enum CpuBatchStrategy {
Auto,
Sequential,
OuterParallel,
ProviderItems,
WholeBatchVendor,
}Expand description
How the items of one batched operation are executed.
Examples
use tenferro_cpu::CpuBatchStrategy;
assert_eq!(CpuBatchStrategy::default(), CpuBatchStrategy::Auto);Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Auto
Choose a supported route from the thresholds and the provider.
Sequential
Sequential batch, sequential items: no parallelism at all.
OuterParallel
Outer-parallel batch: tenferro lanes, each running items sequentially.
ProviderItems
Sequential batch whose items may use the provider’s own parallelism.
WholeBatchVendor
One vendor batch call for the whole batch, with no tenferro fan-out.