pub enum ResolvedCpuPlacement {
NumaNode {
id: NumaNodeId,
cpus: CpuSet,
},
AllAllowed {
cpus: CpuSet,
},
}Expand description
Concrete CPU placement resolved for a managed domain or declared by an external domain.
Examples
use tenferro_cpu::{CpuId, CpuSet, ResolvedCpuPlacement};
let placement = ResolvedCpuPlacement::AllAllowed {
cpus: CpuSet::new([CpuId::new(0)])?,
};
assert_eq!(placement.cpus().len(), 1);Variants
NumaNode
A concrete OS NUMA-node placement.
Fields

id: NumaNodeIdThe sparse OS NUMA node ID.
AllAllowed
A resolved or declared complete process-affinity CPU set.
Implementations
Sourceimpl ResolvedCpuPlacement
impl ResolvedCpuPlacement
Sourcepub fn cpus(&self) -> &CpuSet
pub fn cpus(&self) -> &CpuSet
Return the concrete logical CPU set resolved or declared for this placement.
Examples
use tenferro_cpu::{CpuId, CpuSet, ResolvedCpuPlacement};
let placement = ResolvedCpuPlacement::AllAllowed {
cpus: CpuSet::new([CpuId::new(1), CpuId::new(2)])?,
};
assert_eq!(placement.cpus().as_usize_vec(), vec![1, 2]);Sourcepub fn node_id(&self) -> Option<NumaNodeId>
pub fn node_id(&self) -> Option<NumaNodeId>
Return the OS NUMA node ID for a node placement.
Examples
use tenferro_cpu::{CpuId, CpuSet, NumaNodeId, ResolvedCpuPlacement};
let placement = ResolvedCpuPlacement::NumaNode {
id: NumaNodeId::new(7),
cpus: CpuSet::new([CpuId::new(3)])?,
};
assert_eq!(placement.node_id(), Some(NumaNodeId::new(7)));Trait Implementations
Sourceimpl Clone for ResolvedCpuPlacement
impl Clone for ResolvedCpuPlacement
Sourcefn clone(&self) -> ResolvedCpuPlacement
fn clone(&self) -> ResolvedCpuPlacement
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResolvedCpuPlacement
impl Debug for ResolvedCpuPlacement
Sourceimpl PartialEq for ResolvedCpuPlacement
impl PartialEq for ResolvedCpuPlacement
Sourcefn eq(&self, other: &ResolvedCpuPlacement) -> bool
fn eq(&self, other: &ResolvedCpuPlacement) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for ResolvedCpuPlacement
impl StructuralPartialEq for ResolvedCpuPlacement