current_cpu_execution

Function current_cpu_execution 

pub fn current_cpu_execution() -> CpuThreadExecution
Report what CPU execution the current thread is inside, including a managed Rayon worker running a session or scope callback.

Examples

use tenferro_cpu::{current_cpu_execution, CpuThreadExecution};

assert_eq!(current_cpu_execution(), CpuThreadExecution::Idle);