pub enum CpuProviderOutcome {
Executed,
Unsupported(CpuProviderUnsupported),
}Expand description
Result of attempting a validated request through one provider slot.
Examples
use tenferro_cpu::provider::{CpuProviderOutcome, CpuProviderUnsupported};
let outcome = CpuProviderOutcome::Unsupported(
CpuProviderUnsupported::RuntimeUnavailable,
);
assert!(matches!(outcome, CpuProviderOutcome::Unsupported(_)));Variants
Executed
The provider fully executed the request.
Unsupported(CpuProviderUnsupported)
The provider did not mutate the output and resolution may continue.