#[non_exhaustive]pub enum CpuProviderUnsupported {
DType(DType),
Rank {
lhs: usize,
rhs: usize,
},
Layout(CpuOperand),
Conjugation,
Accumulation,
StridedBatch,
Grouped,
RuntimeUnavailable,
}Expand description
Allocation-free reason that a provider cannot execute a validated request.
An unsupported outcome must be reported before the provider mutates the output.
Examples
use tenferro_cpu::provider::CpuProviderUnsupported;
assert_eq!(
CpuProviderUnsupported::RuntimeUnavailable,
CpuProviderUnsupported::RuntimeUnavailable,
);Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
DType(DType)
The provider does not implement the scalar dtype.
Rank
The provider does not implement the input ranks.
Layout(CpuOperand)
The provider does not implement an operand layout.
Conjugation
The provider cannot implement the requested conjugation.
Accumulation
The provider cannot implement the requested alpha/beta update.
StridedBatch
The provider cannot implement a strided batch.
Grouped
The provider cannot implement grouped GEMM.
The optional provider runtime is not available in this process.