pub struct CpuGemmRequest<'request, 'input, 'output> { /* private fields */ }Expand description
Validated borrowed GEMM request.
A batch count of one is a single GEMM. A larger batch count is a strided batched GEMM.
Examples
use tenferro_cpu::provider::CpuGemmRequest;
assert!(request.batch_count() >= 1);Implementations
Sourceimpl<'request, 'input, 'output> CpuGemmRequest<'request, 'input, 'output>
impl<'request, 'input, 'output> CpuGemmRequest<'request, 'input, 'output>
Sourcepub fn lhs(&self) -> &TensorRead<'input>
pub fn lhs(&self) -> &TensorRead<'input>
Return the borrowed left input.
Sourcepub fn rhs(&self) -> &TensorRead<'input>
pub fn rhs(&self) -> &TensorRead<'input>
Return the borrowed right input.
Sourcepub fn output(&mut self) -> &mut TensorWrite<'output>
pub fn output(&mut self) -> &mut TensorWrite<'output>
Reborrow the writable output for the duration of the current call.
Sourcepub fn contracted(&self) -> usize
pub fn contracted(&self) -> usize
Return the contracted dimension.
Sourcepub fn batch_count(&self) -> usize
pub fn batch_count(&self) -> usize
Return the number of matrices in this strided batch.
Sourcepub fn lhs_layout(&self) -> CpuBatchedMatrixLayout
pub fn lhs_layout(&self) -> CpuBatchedMatrixLayout
Return the left input matrix layout.
Sourcepub fn rhs_layout(&self) -> CpuBatchedMatrixLayout
pub fn rhs_layout(&self) -> CpuBatchedMatrixLayout
Return the right input matrix layout.
Sourcepub fn output_layout(&self) -> CpuBatchedMatrixLayout
pub fn output_layout(&self) -> CpuBatchedMatrixLayout
Return the output matrix layout.
Sourcepub fn accumulation(&self) -> DotGeneralAccumulation
pub fn accumulation(&self) -> DotGeneralAccumulation
Return conjugation and alpha/beta update semantics.