pub enum CpuBackendKind {
Faer,
Blas,
}Expand description
CPU provider selected by a CpuBackend instance.
CPU provider features are additive at compile time; this runtime selector chooses which compiled provider an individual backend uses for provider-owned kernels such as GEMM.
Examples
use tenferro_cpu::CpuBackendKind;
let kind = CpuBackendKind::default_compiled();
assert!(matches!(kind, CpuBackendKind::Faer | CpuBackendKind::Blas));Variants
Implementations
Sourceimpl CpuBackendKind
impl CpuBackendKind
Sourcepub fn default_compiled() -> Self
pub fn default_compiled() -> Self
Return the default compiled CPU provider.
BLAS is preferred when both BLAS and faer are compiled in because an application that links a BLAS/LAPACK provider normally expects provider-backed kernels to use it by default.
Examples
use tenferro_cpu::CpuBackendKind;
let _kind = CpuBackendKind::default_compiled();Trait Implementations
Sourceimpl Clone for CpuBackendKind
impl Clone for CpuBackendKind
Sourcefn clone(&self) -> CpuBackendKind
fn clone(&self) -> CpuBackendKind
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CpuBackendKind
impl Debug for CpuBackendKind
Sourceimpl Hash for CpuBackendKind
impl Hash for CpuBackendKind
Sourceimpl PartialEq for CpuBackendKind
impl PartialEq for CpuBackendKind
impl Copy for CpuBackendKind
impl Eq for CpuBackendKind
impl StructuralPartialEq for CpuBackendKind