CpuBackend

Struct CpuBackend 

pub struct CpuBackend { /* private fields */ }
CPU execution backend.

Examples

use tenferro_cpu::CpuBackend;

let backend = CpuBackend::new();

Implementations

Source

impl CpuBackend

pub fn new() -> Self

Create a CPU backend using the environment-driven CPU context.

Examples
use tenferro_cpu::CpuBackend;

let backend = CpuBackend::new();
pub fn with_kind(kind: CpuBackendKind) -> Result<Self>

Create a CPU backend using the selected compiled provider.

Examples
use tenferro_cpu::{CpuBackend, CpuBackendKind};

let backend = CpuBackend::with_kind(CpuBackendKind::default_compiled()).unwrap();
assert_eq!(backend.kind(), CpuBackendKind::default_compiled());
pub fn try_new() -> Result<Self>

Try to create a CPU backend using RAYON_NUM_THREADS.

Examples
use tenferro_cpu::CpuBackend;

let backend = CpuBackend::try_new()
    .unwrap_or_else(|_| CpuBackend::with_threads(1).unwrap());
let _ = backend.num_threads();
pub fn from_context(ctx: Arc<CpuContext>) -> Self

Create a CPU backend from an existing context.

Examples
use std::sync::Arc;
use tenferro_cpu::{CpuBackend, CpuContext};

let ctx = Arc::new(CpuContext::with_threads(2).unwrap());
let backend = CpuBackend::from_context(ctx);
assert_eq!(backend.num_threads(), 2);
pub fn from_context_with_buffer_pool_limit( ctx: Arc<CpuContext>, max_retained_capacity_bytes: usize, ) -> Self

Create a CPU backend from an existing context and buffer-pool retention cap.

The cap is measured in retained vector capacity bytes. A cap of zero disables buffer retention.

Examples
use std::sync::Arc;
use tenferro_cpu::{CpuBackend, CpuContext};

let ctx = Arc::new(CpuContext::with_threads(1).unwrap());
let backend = CpuBackend::from_context_with_buffer_pool_limit(ctx, 0);
assert_eq!(backend.buffer_pool_limit_bytes(), 0);
pub fn with_threads(num_threads: usize) -> Result<Self>

Create a CPU backend with a custom thread count.

Examples
use tenferro_cpu::CpuBackend;

let backend = CpuBackend::with_threads(2).unwrap();
assert_eq!(backend.num_threads(), 2);
Errors

Returns an error when num_threads is zero or Rayon rejects the pool.

pub fn with_threads_and_kind( num_threads: usize, kind: CpuBackendKind, ) -> Result<Self>

Create a CPU backend with a custom thread count and provider.

Examples
use tenferro_cpu::{CpuBackend, CpuBackendKind};

let backend = CpuBackend::with_threads_and_kind(
    1,
    CpuBackendKind::default_compiled(),
)?;
assert_eq!(backend.num_threads(), 1);
Errors

Returns an error when num_threads is zero, Rayon rejects the pool, or the selected provider is unavailable.

pub fn kind(&self) -> CpuBackendKind

Return the runtime CPU provider selected by this backend.

Examples
use tenferro_cpu::{CpuBackend, CpuBackendKind};

let backend = CpuBackend::new();
assert_eq!(backend.kind(), CpuBackendKind::default_compiled());
pub fn num_threads(&self) -> usize

Return the number of threads in this backend’s CPU context.

Examples
use tenferro_cpu::CpuBackend;

let backend = CpuBackend::with_threads(2).unwrap();
assert_eq!(backend.num_threads(), 2);
pub fn buffer_pool_len(&self) -> usize

Number of retained typed host buffers currently held by this backend.

Examples
use tenferro_cpu::CpuBackend;

let backend = CpuBackend::new();
assert_eq!(backend.buffer_pool_len(), 0);
pub fn buffer_pool_stats(&self) -> BufferPoolStats

Snapshot reusable typed host buffers currently retained by this backend.

Examples
use tenferro_cpu::CpuBackend;

let backend = CpuBackend::new();
let stats = backend.buffer_pool_stats();
assert_eq!(stats.buffers, 0);
assert_eq!(stats.capacity_bytes, 0);
pub fn buffer_pool_cache_stats(&self) -> CacheStats

Return cache-style stats for the CPU buffer pool.

Examples
use tenferro_cpu::CpuBackend;

let backend = CpuBackend::new();
let stats = backend.buffer_pool_cache_stats();
assert_eq!(stats.entries, 0);
assert_eq!(stats.retained_bytes, 0);
pub fn buffer_pool_limit_bytes(&self) -> usize

Current CPU buffer-pool retention limit in bytes.

Examples
use std::sync::Arc;
use tenferro_cpu::{CpuBackend, CpuContext};

let backend = CpuBackend::from_context_with_buffer_pool_limit(
    Arc::new(CpuContext::with_threads(1).unwrap()),
    4096,
);
assert_eq!(backend.buffer_pool_limit_bytes(), 4096);
pub fn set_buffer_pool_limit_bytes( &mut self, max_retained_capacity_bytes: usize, )

Update the CPU buffer-pool retention limit in bytes.

Shrinking the limit evicts retained buffers immediately. A limit of zero disables buffer retention.

Examples
use tenferro_cpu::CpuBackend;

let mut backend = CpuBackend::new();
backend.set_buffer_pool_limit_bytes(0);
assert_eq!(backend.buffer_pool_limit_bytes(), 0);
assert_eq!(backend.buffer_pool_len(), 0);
pub fn reset_buffer_pool(&mut self)

Reset reusable typed host buffers currently retained by this backend.

This releases pool-owned vectors to the process allocator. Operating system RSS may not fall immediately because allocators can retain freed pages for future allocations.

Examples
use tenferro_cpu::CpuBackend;

let mut backend = CpuBackend::new();
backend.reset_buffer_pool();
assert_eq!(backend.buffer_pool_len(), 0);
pub fn install<R: Send>(&self, op: impl FnOnce() -> R + Send) -> R

Run a closure in this backend’s CPU execution scope.

Examples
use tenferro_cpu::CpuBackend;

let backend = CpuBackend::with_threads(1).unwrap();
let value = backend.install(|| 1 + 1);
assert_eq!(value, 2);